@@ -1,5 +1,5 @@
 /*
- * $Id: misc_conv.c,v 1.2 1999/06/19 20:49:09 morgan Exp $
+ * $Id: misc_conv.c,v 1.3 1999/07/04 23:24:26 morgan Exp $
  *
  * A generic conversation function for text based applications
  *
@@ -46,7 +46,7 @@ static void pam_misc_conv_delete_binary(void **delete_me)
 	unsigned char *packet = *(unsigned char **)delete_me;
 	int length;
 
-	length = 4+(packet[0]<<24)+(packet[1]<<16)+(packet[2]<<8)+packet[3];
+	length = (packet[0]<<24)+(packet[1]<<16)+(packet[2]<<8)+packet[3];
 	memset(packet, 0, length);
 	free(packet);
 	*delete_me = packet = NULL;
@@ -289,15 +289,6 @@ int misc_conv(int num_msg, const struct pam_message **msgm,
 
 	    break;
 	}
-	case PAM_BINARY_MSG:
-	{
-	    const void *pack_in = msgm[count]->msg;
-	    if (!pam_binary_handler_fn
-		|| pam_binary_handler_fn(pack_in, NULL) != PAM_SUCCESS) {
-		goto failed_conversation;
-	    }
-	    break;
-	}
 	default:
 	    fprintf(stderr, "erroneous conversation (%d)\n"
 		    ,msgm[count]->msg_style);
@@ -338,7 +329,6 @@ failed_conversation:
 		break;
 	    case PAM_ERROR_MSG:
 	    case PAM_TEXT_INFO:
-	    case PAM_BINARY_MSG:
 		/* should not actually be able to get here... */
 		free(reply[count].resp);
 	    }                                            
