@@ -17,9 +17,14 @@
 #error THIS CODE IS KNOWN TO WORK ONLY ON LINUX !!!
 #endif 
 
+# define _GNU_SOURCE
+# include <features.h>
+
 #include <stdio.h>
 #include <unistd.h>
+#ifndef __USE_POSIX2
 #define __USE_POSIX2
+#endif /* __USE_POSIX2 */
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -276,7 +281,7 @@ static void process_limit(int source, const char *lim_type,
     int limit_item;
     int limit_type = 0;
     long limit_value;
-    char **endptr = (char **) &lim_value;
+    const char **endptr = &lim_value;
     const char *value_orig = lim_value;
         
     if (ctrl & PAM_DEBUG_ARG)
@@ -360,32 +365,34 @@ static void process_limit(int source, const char *lim_type,
     if (limit_item != LIMIT_LOGIN && limit_item != LIMIT_NUMSYSLOGINS 
 		    && limit_item != LIMIT_PRI
 		    ) {
-        if (limit_type & LIMIT_SOFT)
-            if (limits[limit_item].src_soft < source)
+        if (limit_type & LIMIT_SOFT) {
+	    if (limits[limit_item].src_soft < source) {
                 return;
-            else {
+	    } else {
                 limits[limit_item].limit.rlim_cur = limit_value;
                 limits[limit_item].src_soft = source;
             }
-        if (limit_type & LIMIT_HARD)
-            if (limits[limit_item].src_hard < source)
+	}
+        if (limit_type & LIMIT_HARD) {
+	    if (limits[limit_item].src_hard < source) {
                 return;
-            else {
+            } else {
                 limits[limit_item].limit.rlim_max = limit_value;
                 limits[limit_item].src_hard = source;
             }
+	}
     } else 
 	if (limit_item == LIMIT_PRI) {
 		/* additional check */
 		priority = ((limit_value>0)?limit_value:0);
-	} 
-	else
-	        if (login_limit_def < source)
+	} else {
+	        if (login_limit_def < source) {
 	            return;
-	        else {
+	        } else {
 	            login_limit = limit_value;
 	            login_limit_def = source;
         	}
+	}
     return;    
 }
 
