@@ -1,5 +1,5 @@
 /*
- * $Id: pam_pwdb.c,v 1.4 1999/07/05 03:44:51 morgan Exp $
+ * $Id: pam_pwdb.c,v 1.5 1999/07/08 05:02:02 morgan Exp $
  *
  * This is the single file that will be compiled for pam_unix.
  * it includes each of the modules that have beed defined in the .-c
@@ -14,12 +14,16 @@
  */
 
 static const char rcsid[] =
-"$Id: pam_pwdb.c,v 1.4 1999/07/05 03:44:51 morgan Exp $\n"
+"$Id: pam_pwdb.c,v 1.5 1999/07/08 05:02:02 morgan Exp $\n"
 " - PWDB Pluggable Authentication module. <morgan@linux.kernel.org>"
 ;
 
 /* #define DEBUG */
 
+#define _SVID_SOURCE
+#define _BSD_SOURCE
+#define _BSD_COMPAT
+
 #ifdef linux
 # define _GNU_SOURCE
 # include <features.h>
@@ -36,9 +40,6 @@ static const char rcsid[] =
 #include <fcntl.h>
 #include <ctype.h>
 
-#define _SVID_SOURCE
-#define __USE_BSD
-#define _BSD_COMPAT
 #include <sys/time.h>
 #include <unistd.h>
 
