@@ -1,7 +1,7 @@
 /*
  * pam_tally.c
  * 
- * $Id: pam_tally.c,v 1.3 1999/06/19 20:56:50 morgan Exp $
+ * $Id: pam_tally.c,v 1.5 1999/07/04 23:53:38 morgan Exp $
  */
 
 
@@ -26,6 +26,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/param.h>
+#include "faillog.h"
 
 #ifndef TRUE
 #define TRUE  1L
@@ -67,6 +68,9 @@ enum TALLY_RESET {
 # define FILENAME_MAX MAXPATHLEN
 #endif
 
+static struct faillog faillog;
+static time_t fail_time;
+
 /*---------------------------------------------------------------------*/
 
 /* some syslogging */
@@ -145,7 +149,7 @@ static int get_tally( tally_t *tally,
         _pam_log(LOG_ALERT, "Couldn't create %s",filename);
         return PAM_AUTH_ERR;
       }
-      lstat_ret = lstat(fileno(*TALLY),&fileinfo);
+      lstat_ret = fstat(fileno(*TALLY),&fileinfo);
       fclose(*TALLY);
     }
 
@@ -174,14 +178,17 @@ static int get_tally( tally_t *tally,
       return PAM_AUTH_ERR;
     }
 
-    if ( fseek( *TALLY, uid * sizeof (tally_t), SEEK_SET ) ) {
-      _pam_log(LOG_ALERT, "fseek failed %s", filename);
-      return PAM_AUTH_ERR;
-    }
-    
-    if ( ( fread(tally, sizeof(tally_t), 1, *TALLY) )==0 ) {
-      *tally=0; /* Assuming a gappy filesystem */
+    if ( fseek( *TALLY, uid * sizeof faillog, SEEK_SET ) ) {
+          _pam_log(LOG_ALERT, "fseek failed %s", filename);
+                return PAM_AUTH_ERR;
+     }
+                    
+
+    if ( ( fread((char *) &faillog, sizeof faillog, 1, *TALLY) )==0 ) {
+          *tally=0; /* Assuming a gappy filesystem */
     }
+    *tally = faillog.fail_cnt;    
+              
     return PAM_SUCCESS;
   }
 
@@ -196,12 +203,12 @@ static int set_tally( tally_t tally,
   {
     if ( tally!=TALLY_HI ) 
       {
-        if ( fseek( *TALLY, uid * sizeof(tally_t), SEEK_SET ) ) {
-          _pam_log(LOG_ALERT, "fseek failed %s", filename);
-          return PAM_AUTH_ERR;
+        if ( fseek( *TALLY, uid * sizeof faillog, SEEK_SET ) ) {
+                  _pam_log(LOG_ALERT, "fseek failed %s", filename);
+                            return PAM_AUTH_ERR;
         }
-        
-        if ( fwrite(&tally, sizeof(tally_t), 1, *TALLY)==0 ) {
+        faillog.fail_cnt = tally;                                    
+        if ( fwrite((char *) &faillog, sizeof faillog, 1, *TALLY)==0 ) {
           _pam_log(LOG_ALERT, "tally update (fputc) failed.", filename);
           return PAM_AUTH_ERR;
         }
@@ -287,12 +294,25 @@ static int tally_bump (int inc,
     FILE
       *TALLY = NULL;
     const char
-      *user  = NULL;
+      *user  = NULL,
+      *remote_host = NULL;
 
     int i=pam_get_uid(pamh, &uid, &user);
     if ( i != PAM_SUCCESS ) RETURN_ERROR( i );
 
     i=get_tally( &tally, uid, filename, &TALLY );
+    fail_time = faillog.fail_time;      /* to remember old fail time (for locktime) */
+    faillog.fail_time = (time_t) time( (time_t *) 0);
+    (void) pam_get_item(pamh, PAM_RHOST, (const void **)&remote_host);
+    if (!remote_host)
+    {
+    	strcpy(faillog.fail_line, "unknown");
+    }
+    else
+    {
+    	strncpy(faillog.fail_line, remote_host, (size_t)sizeof(faillog.fail_line));
+	faillog.fail_line[sizeof(faillog.fail_line)-1] = 0;
+    }
     if ( i != PAM_SUCCESS ) { if (TALLY) fclose(TALLY); RETURN_ERROR( i ); }
     
     if ( no_magic_root || getuid() ) {       /* no_magic_root kills uid test */
@@ -373,6 +393,8 @@ PAM_FUNCTION( pam_sm_acct_mgmt ) {
   char
     no_magic_root          = FALSE,
     even_deny_root_account = FALSE;
+  char  per_user	    = FALSE;    /* if true then deny=.fail_max for user */
+  char  no_lock_time	    = FALSE;	/* if true then don't use .fail_locktime */
 
   const char
     *user                  = NULL;
@@ -427,6 +449,14 @@ PAM_FUNCTION( pam_sm_acct_mgmt ) {
       else if ( ! strcmp( *argv, "onerr=succeed" ) ) {
         fail_on_error=FALSE;
       }
+      else if ( ! strcmp( *argv, "per_user" ) )
+      {
+      	per_user = TRUE;
+      }
+      else if ( ! strcmp( *argv, "no_lock_time") )
+      {
+      	no_lock_time = TRUE;
+      }
       else {
         _pam_log(LOG_ERR, MODULE_NAME ": unknown option; %s",*argv);
       }
@@ -445,6 +475,17 @@ PAM_FUNCTION( pam_sm_acct_mgmt ) {
       
       /* To deny or not to deny; that is the question */
       
+      /* if there's .fail_max entry and per_user=TRUE then deny=.fail_max */
+      
+      if ( (faillog.fail_max) && (per_user) ) {deny = faillog.fail_max;}
+      if (faillog.fail_locktime && fail_time && (!no_lock_time) )
+      {
+      	if ( (faillog.fail_locktime + fail_time) > (time_t)time((time_t)0) )
+      	{ 
+      		_pam_log(LOG_NOTICE,"user %s ("UID_FMT") has time limit [%lds left] since last failure.",user,uid,fail_time+faillog.fail_locktime-(time_t)time((time_t)0));
+      		return PAM_AUTH_ERR;
+      	}
+      }
       if (
         ( deny != 0 ) &&                     /* deny==0 means no deny        */
         ( tally > deny ) &&                  /* tally>deny means exceeded    */
@@ -470,7 +511,11 @@ PAM_FUNCTION( pam_sm_acct_mgmt ) {
       
       if ( reset == TALLY_RESET_RESET ) { tally=0; }
     }
-    
+    if (tally == 0)
+    {
+    	faillog.fail_time = (time_t) 0;
+    	strcpy(faillog.fail_line, "");	
+    }
     i=set_tally( tally, uid, filename, &TALLY );
     if ( i != PAM_SUCCESS ) { if (TALLY) fclose(TALLY); RETURN_ERROR( i ); }
   }
@@ -611,7 +656,11 @@ int main ( int argc, char **argv ) {
     for ( ; !feof(TALLY); uid++ ) {
       tally_t tally;
       struct passwd *pw;
-      if ( ! fread(&tally, sizeof(tally_t), 1, TALLY) || ! tally ) continue;
+      if ( ! fread((char *) &faillog, sizeof faillog, 1, TALLY) || ! faillog.fail_cnt ) {
+      	tally=faillog.fail_cnt;
+      	continue;
+      	}
+      tally = faillog.fail_cnt;	
       
       if ( ( pw=getpwuid(uid) ) ) {
         printf("User %s\t("UID_FMT")\t%s "TALLY_FMT"\n",pw->pw_name,uid,
