@@ -34,6 +34,8 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#define _BSD_SOURCE
+
 #ifdef linux
 #define _GNU_SOURCE
 #include <features.h>
@@ -42,7 +44,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#define __USE_BSD
 #include <unistd.h>
 #include <sys/types.h>
 #include <syslog.h>
