@@ -35,6 +35,9 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#define _BSD_SOURCE
+#define __USE_SVID
+
 #ifdef linux
 #define _GNU_SOURCE
 #include <features.h>
@@ -45,10 +48,8 @@
 #include <stdarg.h>
 #include <string.h>
 #include <malloc.h>
-#define __USE_BSD
 #include <unistd.h>
 #include <errno.h>
-#define __USE_SVID
 #include <pwd.h>
 #include <syslog.h>
 #include <shadow.h>
